@@ -9,7 +9,7 @@ from plotly.subplots import make_subplots
 
 from copy import deepcopy
 from stocktrends import Renko
-from portfoliotools.screener.utility.util import getHistoricStockPrices, ema, cum_pattern, smooth_avg, slope, backTestStrategy
+from portfoliotools.screener.utility.util import getHistoricStockPrices, ema, cum_pattern, smooth_avg, slope, backTestStrategy, memoize
 from portfoliotools.screener.utility.constant import WILLIAM_K_UL, WILLIAM_K_LL, fundamental_info_cols
 from portfoliotools.screener.stock_fundamentals import StockFundamentals
 
@@ -220,6 +220,7 @@ class StockDetail( object ):
             df['Return'] = -999
             return df.dropna()
         
+    @memoize
     def get_atr_results( self ):
         
         info = dict()
@@ -326,7 +327,7 @@ class StockDetail( object ):
             info['OBV Slope']               = round(details['OBV Index Slope'].values[0],2)
             info['OBV Signal']              = details['Signal'][0]
             info['OBV Passive Portfolio']   = round(details['Passive Portfolio'].values[0],2)
-            info['OBV Active Portfolio']    = round(details['Passive Portfolio'].values[0],2)
+            info['OBV Active Portfolio']    = round(details['Active Portfolio'].values[0],2)
         except:
             log.error("Error calculating OBV Results - {0}".format(self.name))
             info['OBV Value']               = -999
